.. _physics_vector:

=========================
The Physics Vector Module
=========================

.. topic:: Abstract

   In this documentation the components of the sympy.physics.vector module
   have been discussed. :mod:`sympy.physics.vector` has been written to
   facilitate the operations pertaining to 3-dimensional vectors, as functions
   of time or otherwise, in :mod:`sympy.physics`.

.. module:: sympy.physics.vector


References for Physics/Vector
================================

.. [WikiDyadics] "Dyadics." Wikipedia, the Free Encyclopedia. Web. 05 Aug.
        2011. <https://en.wikipedia.org/wiki/Dyadics>.
.. [WikiDyadicProducts] "Dyadic Product." Wikipedia, the Free Encyclopedia.
        Web. 05 Aug. 2011. <https://en.wikipedia.org/wiki/Dyadic_product>.
.. [Likins1973] Likins, Peter W. Elements of Engineering Mechanics.
        McGraw-Hill, Inc. 1973. Print.

Guide to Vector
===============

.. toctree::
   :titlesonly:

   vectors.rst
   kinematics.rst
   advanced.rst
   fields.rst
   api/index.rst
